<!-- markdownlint-disable -->

<a href="..\..\qtstrap\widgets\persistent_tab_widget.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `widgets.persistent_tab_widget`




**Global Variables**
---------------
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**


---

<a href="..\..\qtstrap\widgets\persistent_tab_widget.py#L4"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `PersistentTabWidget`




<a href="..\..\qtstrap\widgets\persistent_tab_widget.py#L5"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentTabWidget.__init__`

```python
__init__(name, tabs=None, *args, **kwargs)
```








---

<a href="..\..\qtstrap\widgets\persistent_tab_widget.py#L87"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentTabWidget.close_tab`

```python
close_tab(index)
```





---

<a href="..\..\qtstrap\widgets\persistent_tab_widget.py#L30"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentTabWidget.menu`

```python
menu(pos) → None
```





---

<a href="..\..\qtstrap\widgets\persistent_tab_widget.py#L84"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentTabWidget.move_tab`

```python
move_tab(old, new)
```





---

<a href="..\..\qtstrap\widgets\persistent_tab_widget.py#L40"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentTabWidget.restore_state`

```python
restore_state(tabs=None)
```





---

<a href="..\..\qtstrap\widgets\persistent_tab_widget.py#L72"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentTabWidget.tab_order`

```python
tab_order()
```





---

<a href="..\..\qtstrap\widgets\persistent_tab_widget.py#L35"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentTabWidget.unhide_all`

```python
unhide_all()
```





---

<a href="..\..\qtstrap\widgets\persistent_tab_widget.py#L78"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PersistentTabWidget.visible_tabs`

```python
visible_tabs()
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
